# ReZip

Repack zip files with the possibility to update metadata, e.g., Unix
access right bits.


GitLab page: https://gitlab.com/dfritzsche/python-rezip


## Using rezip

Usage: rezip [--inplace] [--normalize-access-rights] INPUT OUTPUT

* --inplace

  Repack in place

* --normalize-access-rights

  Normalize Unix access rights

* INPUT

  The zip file to read

* OUTPUT

  The zip file to create and write to
